pub struct ArticleClient<'a> { /* private fields */ }Expand description
Article API client.
Implementations
Sourceimpl<'a> ArticleClient<'a>
impl<'a> ArticleClient<'a>
Sourcepub async fn like(&self, params: ArticleLikeParams) -> BpiResult<Option<Value>>
pub async fn like(&self, params: ArticleLikeParams) -> BpiResult<Option<Value>>
Likes or unlikes an article and returns the canonical payload result.
Sourcepub async fn coin(
&self,
params: ArticleCoinParams,
) -> BpiResult<CoinResponseData>
pub async fn coin( &self, params: ArticleCoinParams, ) -> BpiResult<CoinResponseData>
Gives coins to an article and returns the canonical payload result.
Sourcepub async fn favorite(
&self,
params: ArticleFavoriteParams,
) -> BpiResult<Option<Value>>
pub async fn favorite( &self, params: ArticleFavoriteParams, ) -> BpiResult<Option<Value>>
Favorites an article and returns the canonical payload result.
Sourcepub async fn unfavorite(
&self,
params: ArticleFavoriteParams,
) -> BpiResult<Option<Value>>
pub async fn unfavorite( &self, params: ArticleFavoriteParams, ) -> BpiResult<Option<Value>>
Removes an article from favorites and returns the canonical payload result.
Sourceimpl<'a> ArticleClient<'a>
impl<'a> ArticleClient<'a>
Sourcepub async fn info(
&self,
params: ArticleInfoParams,
) -> BpiResult<ArticleInfoData>
pub async fn info( &self, params: ArticleInfoParams, ) -> BpiResult<ArticleInfoData>
Gets article summary information.
Sourcepub async fn view(
&self,
params: ArticleViewParams,
) -> BpiResult<ArticleViewData>
pub async fn view( &self, params: ArticleViewParams, ) -> BpiResult<ArticleViewData>
Gets article content.
Sourcepub async fn cards(&self, params: ArticleCardsParams) -> BpiResult<CardData>
pub async fn cards(&self, params: ArticleCardsParams) -> BpiResult<CardData>
Gets article, video, or live cards referenced by article content.
Sourcepub async fn articles(
&self,
params: ArticleArticlesInfoParams,
) -> BpiResult<ArticlesData>
pub async fn articles( &self, params: ArticleArticlesInfoParams, ) -> BpiResult<ArticlesData>
Gets article list information.