pub struct CommentClient<'a> { /* private fields */ }Expand description
Comment API client.
Implementations
Sourceimpl<'a> CommentClient<'a>
impl<'a> CommentClient<'a>
Sourcepub async fn add(&self, params: CommentAddParams) -> BpiResult<CommentData>
pub async fn add(&self, params: CommentAddParams) -> BpiResult<CommentData>
Publishes a comment and returns the canonical payload result.
Sourcepub async fn like(
&self,
params: CommentActionParams,
) -> BpiResult<Option<Value>>
pub async fn like( &self, params: CommentActionParams, ) -> BpiResult<Option<Value>>
Likes or unlikes a comment and returns the canonical payload result.
Sourcepub async fn dislike(
&self,
params: CommentActionParams,
) -> BpiResult<Option<Value>>
pub async fn dislike( &self, params: CommentActionParams, ) -> BpiResult<Option<Value>>
Dislikes or undislikes a comment and returns the canonical payload result.
Sourcepub async fn delete(
&self,
params: CommentDeleteParams,
) -> BpiResult<Option<Value>>
pub async fn delete( &self, params: CommentDeleteParams, ) -> BpiResult<Option<Value>>
Deletes a comment and returns the canonical payload result.
Sourceimpl<'a> CommentClient<'a>
impl<'a> CommentClient<'a>
Sourcepub async fn list(
&self,
params: CommentListParams,
) -> BpiResult<CommentListData>
pub async fn list( &self, params: CommentListParams, ) -> BpiResult<CommentListData>
Gets the main comment list for a target comment area.
Sourcepub async fn replies(
&self,
params: CommentRepliesParams,
) -> BpiResult<CommentListData>
pub async fn replies( &self, params: CommentRepliesParams, ) -> BpiResult<CommentListData>
Gets replies under a root comment.
Sourcepub async fn hot(
&self,
params: CommentHotParams,
) -> BpiResult<Option<HotCommentData>>
pub async fn hot( &self, params: CommentHotParams, ) -> BpiResult<Option<HotCommentData>>
Gets hot comments under a root comment when the API returns a payload.
Sourcepub async fn count(&self, params: CommentCountParams) -> BpiResult<CountData>
pub async fn count(&self, params: CommentCountParams) -> BpiResult<CountData>
Gets the total comment count for a target comment area.