DynamicClient

Struct DynamicClient 

pub struct DynamicClient<'a> { /* private fields */ }
Dynamic API client.

Implementations

Source

impl<'a> DynamicClient<'a>

pub async fn like(&self, params: DynamicLikeParams) -> BpiResult<Option<Value>>

Likes or unlikes a dynamic item and returns the canonical payload result.

pub async fn delete_draft( &self, params: DynamicDraftDeleteParams, ) -> BpiResult<Option<Value>>

Deletes a scheduled dynamic draft and returns the canonical payload result.

pub async fn set_top( &self, params: DynamicTopParams, ) -> BpiResult<Option<Value>>

Sets a dynamic item as top and returns the canonical payload result.

pub async fn remove_top( &self, params: DynamicTopParams, ) -> BpiResult<Option<Value>>

Removes a dynamic item from top and returns the canonical payload result.

Source

impl<'a> DynamicClient<'a>

pub async fn all(&self, params: DynamicAllParams) -> BpiResult<DynamicAllData>

Gets the followed dynamic feed.

pub async fn check_new( &self, params: DynamicCheckNewParams, ) -> BpiResult<DynamicUpdateData>

Checks whether the dynamic feed has new items.

pub async fn nav_feed( &self, params: DynamicNavFeedParams, ) -> BpiResult<DynamicNavData>

Gets dynamic items shown in the navigation feed.

pub async fn feed_banner(&self) -> BpiResult<DynamicBannerData>

Gets the dynamic feed banner.

pub async fn detail( &self, params: DynamicDetailParams, ) -> BpiResult<DynamicDetailData>

Gets a dynamic item detail.

pub async fn reactions( &self, params: DynamicReactionsParams, ) -> BpiResult<DynamicReactionData>

Gets reaction users for a dynamic item.

pub async fn lottery_notice( &self, params: DynamicLotteryNoticeParams, ) -> BpiResult<DynamicLotteryData>

Gets lottery notice detail for a dynamic item.

pub async fn forwards( &self, params: DynamicForwardsParams, ) -> BpiResult<DynamicForwardData>

Gets forwards for a dynamic item.

pub async fn pics( &self, params: DynamicPicsParams, ) -> BpiResult<Vec<DynamicPic>>

Gets pictures for a dynamic item.

pub async fn forward_item( &self, params: DynamicForwardItemParams, ) -> BpiResult<DynamicForwardInfoData>

Gets a forwarded dynamic item.

pub async fn live_users( &self, params: DynamicLiveUsersParams, ) -> BpiResult<LiveUsersData>

Gets followed users who are currently live.

pub async fn up_users( &self, params: DynamicUpUsersParams, ) -> BpiResult<DynUpUsersData>

Gets followed users with new dynamic content.

pub async fn recent_up(&self) -> BpiResult<RecentUpData>

Gets recently updated followed users.

Source

impl<'a> DynamicClient<'a>

pub async fn upload_pic( &self, params: DynamicUploadPicParams, ) -> BpiResult<UploadPicData>

Uploads a dynamic image and returns the canonical payload result.

pub async fn create_text( &self, params: DynamicTextCreateParams, ) -> BpiResult<CreateDynamicData>

Publishes a plain-text dynamic and returns the canonical payload result.

pub async fn create_complex( &self, params: DynamicComplexCreateParams, ) -> BpiResult<CreateComplexDynamicData>

Publishes a complex dynamic and returns the canonical payload result.