pub struct ElectricClient<'a> { /* private fields */ }Expand description
Electric charging API client.
Implementations
Sourceimpl<'a> ElectricClient<'a>
impl<'a> ElectricClient<'a>
Sourcepub async fn bcoin_quick_pay(
&self,
params: BcoinQuickPayParams,
) -> BpiResult<BcoinQuickPayData>
pub async fn bcoin_quick_pay( &self, params: BcoinQuickPayParams, ) -> BpiResult<BcoinQuickPayData>
Performs B-coin quick electric charging and returns the canonical payload result.
Sourceimpl<'a> ElectricClient<'a>
impl<'a> ElectricClient<'a>
Sourcepub async fn send_message(
&self,
params: ElectricMessageSendParams,
) -> BpiResult<Option<Value>>
pub async fn send_message( &self, params: ElectricMessageSendParams, ) -> BpiResult<Option<Value>>
Sends an electric charge message and returns the canonical payload result.
Sourcepub async fn reply_remark(
&self,
params: ElectricRemarkReplyParams,
) -> BpiResult<u64>
pub async fn reply_remark( &self, params: ElectricRemarkReplyParams, ) -> BpiResult<u64>
Replies to an electric charge remark and returns the canonical payload result.
Sourceimpl<'a> ElectricClient<'a>
impl<'a> ElectricClient<'a>
Sourcepub async fn month_up_list(&self, up_mid: i64) -> BpiResult<ChargeMonthUpData>
pub async fn month_up_list(&self, up_mid: i64) -> BpiResult<ChargeMonthUpData>
Gets the monthly charging public list for an UP user.
Sourcepub async fn video_show(
&self,
mid: i64,
aid: Option<i64>,
bvid: Option<&str>,
) -> BpiResult<VideoElecShowData>
pub async fn video_show( &self, mid: i64, aid: Option<i64>, bvid: Option<&str>, ) -> BpiResult<VideoElecShowData>
Gets video charging acknowledgements.
Sourcepub async fn recharge_list(
&self,
page: u64,
page_size: u64,
begin_time: Option<NaiveDate>,
end_time: Option<NaiveDate>,
) -> BpiResult<RechargeData>
pub async fn recharge_list( &self, page: u64, page_size: u64, begin_time: Option<NaiveDate>, end_time: Option<NaiveDate>, ) -> BpiResult<RechargeData>
Gets the authenticated account’s received charging records.
Sourcepub async fn rank_recent(
&self,
pn: Option<u64>,
ps: Option<u64>,
) -> BpiResult<ElecRankData>
pub async fn rank_recent( &self, pn: Option<u64>, ps: Option<u64>, ) -> BpiResult<ElecRankData>
Gets recent charging rank history.
Sourcepub async fn charge_record(
&self,
page: u64,
charge_type: u32,
) -> BpiResult<ChargeRecordData>
pub async fn charge_record( &self, page: u64, charge_type: u32, ) -> BpiResult<ChargeRecordData>
Gets the authenticated account’s monthly charging records.
Sourcepub async fn upower_item_detail(
&self,
up_mid: u64,
) -> BpiResult<UpowerItemDetail>
pub async fn upower_item_detail( &self, up_mid: u64, ) -> BpiResult<UpowerItemDetail>
Gets monthly charging item details for an UP user.
Sourcepub async fn charge_follow_info(
&self,
up_mid: u64,
) -> BpiResult<ChargeFollowInfo>
pub async fn charge_follow_info( &self, up_mid: u64, ) -> BpiResult<ChargeFollowInfo>
Gets the authenticated account’s monthly charging relationship with an UP user.
Sourcepub async fn upower_member_rank(
&self,
up_mid: u64,
pn: u64,
ps: u64,
privilege_type: Option<u64>,
) -> BpiResult<MemberRankData>
pub async fn upower_member_rank( &self, up_mid: u64, pn: u64, ps: u64, privilege_type: Option<u64>, ) -> BpiResult<MemberRankData>
Gets the monthly charging member rank for an UP user.
Sourcepub async fn remark_list(
&self,
pn: Option<u64>,
ps: Option<u64>,
begin: Option<NaiveDate>,
end: Option<NaiveDate>,
) -> BpiResult<ElecRemarkList>
pub async fn remark_list( &self, pn: Option<u64>, ps: Option<u64>, begin: Option<NaiveDate>, end: Option<NaiveDate>, ) -> BpiResult<ElecRemarkList>
Lists charging remarks received by the authenticated account.
Sourcepub async fn remark_detail(&self, id: u64) -> BpiResult<ElecRemarkDetail>
pub async fn remark_detail(&self, id: u64) -> BpiResult<ElecRemarkDetail>
Gets one charging remark by id.