NoteClient

Struct NoteClient 

pub struct NoteClient<'a> { /* private fields */ }
Note API client.

Implementations

Source

impl<'a> NoteClient<'a>

pub async fn add(&self, params: NoteAddParams) -> BpiResult<NoteAddResponseData>

Saves a video note and returns the canonical payload result.

pub async fn delete(&self, params: NoteDeleteParams) -> BpiResult<Option<Value>>

Deletes a video note and returns the canonical payload result.

Source

impl<'a> NoteClient<'a>

pub async fn is_forbid( &self, params: NoteIsForbidParams, ) -> BpiResult<NoteIsForbidData>

Checks whether notes are forbidden for an archive.

pub async fn private_info( &self, params: NotePrivateInfoParams, ) -> BpiResult<PrivateNoteInfoData>

Gets private note content.

pub async fn public_info( &self, params: NotePublicInfoParams, ) -> BpiResult<PublicNoteInfoData>

Gets public note content.

pub async fn archive_list( &self, params: NoteArchiveListParams, ) -> BpiResult<NoteListArchiveData>

Gets private note IDs for an archive.

pub async fn user_private_list( &self, params: NoteUserPrivateListParams, ) -> BpiResult<PrivateNoteListData>

Gets private notes owned by the current user.

pub async fn public_archive_list( &self, params: NotePublicArchiveListParams, ) -> BpiResult<PublicNoteListArchiveData>

Gets public notes for an archive.

pub async fn user_public_list( &self, params: NoteUserPublicListParams, ) -> BpiResult<PublicNoteListUserData>

Gets public notes authored by a user.